@@ -13,14 +13,14 @@ echo -e "${BLUE}Temp DIR: ${TEMP_DIR}${NC}"
 echo -e "${BLUE}Copying source to temporary build directory${NC}"
 
 # Go to root of directory
-cd ${ROOT}
+cd "${ROOT}"
 
 # Extract version from changelog
-VERSION=$(cat ${ROOT}/debian/changelog | grep -m 1 -oP '(?<=openrazer \()[^\-\)]+')
+VERSION=$(cat "${ROOT}/debian/changelog" | grep -m 1 -oP '(?<=openrazer \()[^\-\)]+')
 ORIG_TAR="openrazer_${VERSION}.orig.tar.gz"
 
 #git archive ${CURRENT_BRANCH} | gzip > ${TEMP_DIR}/${ORIG_TAR}
-tar --exclude-vcs --exclude-vcs-ignores -zcf ${TEMP_DIR}/${ORIG_TAR} -C ${ROOT} .
+tar --exclude-vcs --exclude-vcs-ignores -zcf ${TEMP_DIR}/${ORIG_TAR} -C "${ROOT}" .
 
 
 cd ${TEMP_DIR}
@@ -32,7 +32,7 @@ debuild -S > ${TEMP_DIR}/build.log 2>&1
 result_code=$?
 
 
-cd ${CWD}
+cd "${CWD}"
 
 if [ $result_code = 0 ]; then
     echo -e "${GREEN}Source Deb packages build successfully. Running pbuilder${NC}"
